import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class SquareButtonsMenuExample extends StatefulWidget {
  const SquareButtonsMenuExample({Key? key}) : super(key: key);

  @override
  _SquareButtonsMenuExampleState createState() => _SquareButtonsMenuExampleState();
}

class _SquareButtonsMenuExampleState extends State<SquareButtonsMenuExample> {
  bool checkOne = false;
  bool checkTwo = false;
  bool checkThree = false;
  bool checkFour = false;

  void showSnackBar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text('Opção "$message" selecionada'),
      ),
    );
  }

  void _showSnackbar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(message),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Square Buttons Menu Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Panel(
                title: 'In line',
                content: Center(
                  child: SeniorSquareButtonsMenu(
                    items: [
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Minha equipe',
                          );
                        },
                        icon: FontAwesomeIcons.users,
                        text: 'Minha equipe',
                        type: SeniorSquareButtonsMenuItemType.primary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus feedbacks',
                          );
                        },
                        icon: FontAwesomeIcons.exchangeAlt,
                        text: 'Meus feedbacks',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Períodos em aberto',
                          );
                        },
                        icon: FontAwesomeIcons.calendar,
                        text: 'Períodos em aberto',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Novo atalho',
                          );
                        },
                        icon: FontAwesomeIcons.plus,
                        text: 'Novo atalho',
                        type: SeniorSquareButtonsMenuItemType.ghost,
                      ),
                    ],
                  ),
                ),
              ),
              Panel(
                title: 'Grid',
                content: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Container(
                      padding: const EdgeInsets.symmetric(vertical: 16.0),
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text('Check Minha equipe: ${checkOne ? 'Marcado' : 'Desmarcado'}'),
                          Text('Check Meus feedbacks: ${checkTwo ? 'Marcado' : 'Desmarcado'}'),
                          Text('Check Minhas solicitações: ${checkThree ? 'Marcado' : 'Desmarcado'}'),
                          Text('Check Requisição de férias: ${checkFour ? 'Marcado' : 'Desmarcado'}'),
                        ],
                      ),
                    ),
                    Center(
                      child: SeniorSquareButtonsMenu.grid(
                        crossAxisCount: 3,
                        items: [
                          SeniorSquareButtonsMenuItemData.checkbox(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Minha equipe',
                              );
                            },
                            icon: FontAwesomeIcons.users,
                            text: 'Minha equipe',
                            type: SeniorSquareButtonsMenuItemType.primary,
                            isChecked: checkOne,
                            onCheck: (check) {
                              _showSnackbar(
                                  context: context,
                                  message: 'Check do Minha equipe',
                                );
                              if(check == null) return;
                              setState(() {
                                checkOne = check;
                              });
                            }
                          ),
                          SeniorSquareButtonsMenuItemData.checkbox(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Meus feedbacks',
                              );
                            },
                            icon: FontAwesomeIcons.exchangeAlt,
                            text: 'Meus feedbacks',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                            isChecked:  checkTwo,
                            onCheck: (check) {
                              _showSnackbar(
                                  context: context,
                                  message: 'Check do Meus feedbacks',
                                );
                              if(check == null) return;
                              setState(() {
                                checkTwo = check;
                              });
                            }
                          ),
                          SeniorSquareButtonsMenuItemData.checkbox(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Minhas solicitações',
                              );
                            },
                            icon: FontAwesomeIcons.exchangeAlt,
                            text: 'Minhas solicitações',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                            isChecked: checkThree,
                            onCheck: (check) {
                              _showSnackbar(
                                  context: context,
                                  message: 'Check do Minhas solicitações',
                                );
                              if(check == null) return;
                              setState(() {
                                checkThree = check;
                              });
                            }
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Calendário de férias',
                              );
                            },
                            icon: FontAwesomeIcons.calendarAlt,
                            text: 'Calendário de férias',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Meu perfil',
                              );
                            },
                            icon: FontAwesomeIcons.solidUser,
                            text: 'Meu perfil',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Plugin Teams',
                              );
                            },
                            icon: FontAwesomeIcons.thLarge,
                            text: 'Plugin Teams',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Notificações e alertas',
                              );
                            },
                            icon: FontAwesomeIcons.solidBell,
                            text: 'Notificações e alertas',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Imposto de renda',
                              );
                            },
                            icon: FontAwesomeIcons.moneyCheckAlt,
                            text: 'Imposto de renda',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData.checkbox(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Requisição de férias',
                              );
                            },
                            icon: FontAwesomeIcons.plane,
                            text: 'Requisição de férias',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                            isChecked: checkFour,
                            onCheck: (check) {
                              _showSnackbar(
                                  context: context,
                                  message: 'Check  do Requisição de férias',
                                );
                              if(check == null) return;
                              setState(() {
                                checkFour = check;
                              });
                            }
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Ajuda',
                              );
                            },
                            icon: FontAwesomeIcons.headset,
                            text: 'Ajuda',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Configurações',
                              );
                            },
                            icon: FontAwesomeIcons.cog,
                            text: 'Configurações',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Privacidade e segurança',
                              );
                            },
                            icon: FontAwesomeIcons.shieldAlt,
                            text: 'Privacidade e segurança',
                            type: SeniorSquareButtonsMenuItemType.secondary,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: (){
                              showSnackBar(
                                context: context,
                                message: 'Novo atalho',
                              );
                            },
                            icon: FontAwesomeIcons.plus,
                            text: 'Novo atalho',
                            type: SeniorSquareButtonsMenuItemType.ghost,
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
              Panel(
                title: 'Grid reduzida',
                content: Center(
                  child: SeniorSquareButtonsMenu.grid(
                    crossAxisCount: 9,
                    items: [
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Minha equipe',
                          );
                        },
                        icon: FontAwesomeIcons.users,
                        text: 'Minha equipe',
                        type: SeniorSquareButtonsMenuItemType.primary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meus feedbacks',
                          );
                        },
                        icon: FontAwesomeIcons.exchangeAlt,
                        text: 'Meus feedbacks',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Minhas solicitações',
                          );
                        },
                        icon: FontAwesomeIcons.exchangeAlt,
                        text: 'Minhas solicitações',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Calendário de férias',
                          );
                        },
                        icon: FontAwesomeIcons.calendarAlt,
                        text: 'Calendário de férias',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Meu perfil',
                          );
                        },
                        icon: FontAwesomeIcons.solidUser,
                        text: 'Meu perfil',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Plugin Teams',
                          );
                        },
                        icon: FontAwesomeIcons.thLarge,
                        text: 'Plugin Teams',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Notificações e alertas',
                          );
                        },
                        icon: FontAwesomeIcons.solidBell,
                        text: 'Notificações e alertas',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Imposto de renda',
                          );
                        },
                        icon: FontAwesomeIcons.moneyCheckAlt,
                        text: 'Imposto de renda',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Requisição de férias',
                          );
                        },
                        icon: FontAwesomeIcons.plane,
                        text: 'Requisição de férias',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Ajuda',
                          );
                        },
                        icon: FontAwesomeIcons.headset,
                        text: 'Ajuda',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Configurações',
                          );
                        },
                        icon: FontAwesomeIcons.cog,
                        text: 'Configurações',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Privacidade e segurança',
                          );
                        },
                        icon: FontAwesomeIcons.shieldAlt,
                        text: 'Privacidade e segurança',
                        type: SeniorSquareButtonsMenuItemType.secondary,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: (){
                          showSnackBar(
                            context: context,
                            message: 'Novo atalho',
                          );
                        },
                        icon: FontAwesomeIcons.plus,
                        text: 'Novo atalho',
                        type: SeniorSquareButtonsMenuItemType.ghost,
                      ),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
