import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorBottomSheet {
  static Future<dynamic> showBottomSheet({
    required BuildContext context,
    required double height,
    required List<Widget> content,
    required bool hasCloseButton,
    String? title,
    TextStyle? textStyle,
    VoidCallback? onTapCloseButton,
    bool? isDismissible,
    bool? enableDrag,
  }) {
    return showModalBottomSheet(
      isDismissible: isDismissible ?? false,
      enableDrag: enableDrag ?? false,
      isScrollControlled: true,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(
            SeniorRadius.huge,
          ),
          topRight: Radius.circular(
            SeniorRadius.huge,
          ),
        ),
      ),
      backgroundColor: SeniorColors.pureWhite,
      context: context,
      constraints: BoxConstraints(
        maxHeight: height,
      ),
      builder: (BuildContext context) {
        return Column(
          children: [
            SizedBox(height: SeniorSpacing.medium),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 16),
              child: Row(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Expanded(
                    child: title != null
                        ? Text(
                            title,
                            style: textStyle ?? SeniorTypography.h3(),
                          )
                        : SizedBox.shrink(),
                  ),
                  SizedBox(width: SeniorSpacing.normal),
                  hasCloseButton
                      ? InkWell(
                          child: FaIcon(
                            FontAwesomeIcons.times,
                            size: SeniorTypographyIconSize.CTA,
                            color: SeniorColors.primaryColor300,
                          ),
                          onTap: onTapCloseButton,
                        )
                      : SizedBox.shrink()
                ],
              ),
            ),
            ...content,
          ],
        );
      },
    );
  }
}
