import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorDropdownButton extends StatefulWidget {
  final List<DropdownMenuItem> items;
  final dynamic value;
  final bool disabled;
  final Function(dynamic) onChanged;
  final Function()? onTap;
  final String label;
  final String? helper;
  final IconData? icon;
  final String? Function(dynamic)? validator;

  const SeniorDropdownButton({
    Key? key,
    required this.items,
    required this.value,
    this.disabled = false,
    required this.onChanged,
    this.onTap,
    required this.label,
    this.helper,
    this.icon,
    this.validator,
  }) : super(key: key);

  @override
  _SeniorDropdownButtonState createState() => _SeniorDropdownButtonState();
}

class _SeniorDropdownButtonState extends State<SeniorDropdownButton> {
  String? _validMsg;
  bool _hasError = false;
  String? _errorMsg;

  @override
  void initState() {
    super.initState();
    this._internalValidate(value: widget.value, validateAsError: false);
  }

  void _internalValidate({dynamic value, bool validateAsError = true}) {
    if (widget.validator != null) {
      setState(() {
        this._validMsg = widget.validator!(value);

        if (validateAsError) {
          this._hasError = _validMsg != null;
          this._errorMsg = this._validMsg;
        }
      });
    }
  }

  String? _validate(dynamic value) {
    this._internalValidate(value: value);
    return this._validMsg;
  }

  void _onChanged(dynamic value) {
    widget.onChanged(value);
    this._internalValidate(value: value);
  }

  @override
  Widget build(BuildContext context) {
    return DropdownButtonFormField(
      items: widget.items,
      value: widget.value,
      onChanged: !widget.disabled ? this._onChanged : null,
      onTap: widget.onTap,
      validator: this._validate,
      icon: Icon(
        FontAwesomeIcons.chevronDown,
      ),
      iconSize: SeniorTypographyIconSize.text,
      iconEnabledColor: SeniorColors.neutralColor900,
      iconDisabledColor: SeniorColors.neutralColor400,
      isExpanded: true,
      decoration: InputDecoration(
        contentPadding: EdgeInsets.symmetric(
          horizontal: 12.0,
          vertical: 0,
        ),
        helperText: widget.helper,
        errorText: this._errorMsg,
        prefixIcon: Icon(
          widget.icon,
          size: SeniorTypographyIconSize.CTA,
          color: widget.disabled
              ? SeniorColors.neutralColor400
              : SeniorColors.secondaryColor900,
        ),
        labelText: widget.label,
        labelStyle: SeniorTypography.text(
          color: this._hasError
              ? SeniorColors.manchesterColorRed
              : widget.disabled
                  ? SeniorColors.neutralColor400
                  : SeniorColors.primaryColor600,
        ),
        border: UnderlineInputBorder(
          borderSide: BorderSide(
            color: SeniorColors.secondaryColor500,
            width: 2.0,
          ),
        ),
      ),
      style: SeniorTypography.text(
        color: SeniorColors.neutralColor800,
      ),
    );
  }
}
