import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorSnackBarAction extends SnackBarAction {
  SeniorSnackBarAction({
    required String label,
    required Function() onPressed,
  }) : super(
    label: label,
    onPressed: onPressed,
    textColor: SeniorColors.pureBlack,
    disabledTextColor: SeniorColors.neutralColor500,
  );
} 

abstract class SeniorSnackBar extends SnackBar {
  SeniorSnackBar({
    Key? key,
    required String message,
    IconData? icon,
    Color? iconColor,
    required Color backgroundColor,
    required Color fontColor,
    SeniorSnackBarAction? action,
    Duration? duration,
    DismissDirection? dismissDirection,
  }) : super(
    duration: duration ?? Duration(milliseconds: 4000),
    dismissDirection: dismissDirection ?? DismissDirection.down,
    behavior: SnackBarBehavior.floating,
    backgroundColor: backgroundColor,
    elevation: 1.0,
    action: action,
    content: Row(
      children: [
        Visibility(
          visible: icon != null,
          child: Padding(
            padding: const EdgeInsets.only(
              right: 16.0,
            ),
            child: Icon(
              icon,
              color: iconColor,
              size: SeniorTypographyIconSize.h3,
            ),
          ),
        ),
        Expanded(
          child: Text(
            message,
            style: SeniorTypography.small(
              color: fontColor,
            ),
          ),
        ),
      ],
    ),
  );

  factory SeniorSnackBar.success({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) = _SeniorSnackbarSuccess;

  factory SeniorSnackBar.message({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) = _SeniorSnackbarMessage;

  factory SeniorSnackBar.warning({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) = _SeniorSnackbarWarning;

  factory SeniorSnackBar.error({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) = _SeniorSnackbarError;
}

class _SeniorSnackbarSuccess extends SeniorSnackBar {
  _SeniorSnackbarSuccess({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) : super(
    key: key,
    message: message,
    icon: FontAwesomeIcons.solidCheckCircle,
    iconColor: SeniorColors.manchesterColorGreen,
    backgroundColor: SeniorColors.manchesterColorGreen100,
    fontColor: SeniorColors.pureBlack,
    action: action,
  );
}

class _SeniorSnackbarMessage extends SeniorSnackBar {
  _SeniorSnackbarMessage({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) : super(
    key: key,
    message: message,
    icon: FontAwesomeIcons.infoCircle,
    iconColor: SeniorColors.manchesterColorBlue,
    backgroundColor: SeniorColors.manchesterColorBlue100,
    fontColor: SeniorColors.pureBlack,
    action: action,
  );
}

class _SeniorSnackbarWarning extends SeniorSnackBar {
  _SeniorSnackbarWarning({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) : super(
    key: key,
    message: message,
    icon: FontAwesomeIcons.exclamationTriangle,
    iconColor: SeniorColors.manchesterColorYellow,
    backgroundColor: SeniorColors.manchesterColorYellow100,
    fontColor: SeniorColors.pureBlack,
    action: action,
  );
}

class _SeniorSnackbarError extends SeniorSnackBar {
  _SeniorSnackbarError({
    Key? key,
    required String message,
    SeniorSnackBarAction? action,
  }) : super(
    key: key,
    message: message,
    duration: Duration(seconds: 10),
    dismissDirection:
        action == null ? DismissDirection.down : DismissDirection.none,
    icon: FontAwesomeIcons.solidTimesCircle,
    iconColor: SeniorColors.manchesterColorRed,
    backgroundColor: SeniorColors.manchesterColorRed100,
    fontColor: SeniorColors.pureBlack,
    action: action,
  );
}
