import 'package:flutter/cupertino.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum SeniorSwitchLabelPosition {
  left, right
}

class SeniorSwitchTheme {
  SeniorSwitchTheme._();

  static Color getSwitchActiveColor() {
    return SeniorColors.primaryColor;
  }

  static Color getSwitchTrackColor() {
    return SeniorColors.secondaryColor600;
  }

  static Color getSwitchTextColor({
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.neutralColor900;
    }
    return SeniorColors.secondaryColor300;
  }
}

class SeniorSwitch extends StatelessWidget {
  final String title;
  final bool value;
  final Function(bool?) onChanged;
  final bool disabled;
  final bool fullLenght;
  final SeniorSwitchLabelPosition labelPosition;

  const SeniorSwitch({
    Key? key,
    required this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
    this.fullLenght = false,
    this.labelPosition = SeniorSwitchLabelPosition.left,
  }) : super(key: key);

  Widget buildSwitch() {
    return Container(
      margin: EdgeInsets.fromLTRB(0, 0, 8.0, 0),
      child: CupertinoSwitch(
        value: this.value,
        onChanged: !this.disabled
          ? this.onChanged
          : null,
        activeColor: SeniorSwitchTheme.getSwitchActiveColor(),
        trackColor: SeniorSwitchTheme.getSwitchTrackColor(),
      ),
    );
  }

  Widget buildLabel() {
    return Flexible(
      child: Text(
        this.title,
        style: SeniorTypography.text(color: SeniorSwitchTheme.getSwitchTextColor(isDisabled: this.disabled)),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: this.fullLenght
        ? MainAxisAlignment.spaceBetween
        : MainAxisAlignment.start,
      children: this.labelPosition == SeniorSwitchLabelPosition.left
        ? [buildLabel(), buildSwitch()]
        : [buildSwitch(), buildLabel()],
    );
  }
}